@@ -30,7 +30,7 @@ CREATE TABLE method (
   status_code NOT NULL DEFAULT 200,
   delay NOT NULL DEFAULT 0,
   supported_method NOT NULL DEFAULT 'GET',
-  headers NOT NULL,
+  headers,
   FOREIGN KEY (author_id) REFERENCES user (id),
   FOREIGN KEY (service_id) REFERENCES service (id)
 );
\ No newline at end of file
